@@ -1,4 +1,4 @@
-import requests
+import requests, py2b
 
 
 class player():
@@ -22,4 +22,6 @@ class player():
         self.request = requests.request("GET", f"https://api.2b2t.dev/stats?lastkill={self.username}")
         return self.request.json()
 
-
+    def prioBanned(self):
+        return py2b.check(self.username)
+        
